==> sso-common-2.3.24.20180831.142013-2-sources.jar: cn/com/duiba/sso/api/domain/dto/SystemDto.java <==
package cn.com.duiba.sso.api.domain.dto;

import cn.com.duiba.sso.api.domain.enums.SystemSwitches;
import cn.com.duiba.wolf.utils.SwitchUtils;

import java.io.Serializable;

/**
 * Created by liuyao on 2017/12/5.
 */
public class SystemDto implements Serializable {

    private Long id;
    private String appNameAlias;
    private String appName;
    private String icon;
    private String homeUrl;
    private Long switches;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppNameAlias() {
        return appNameAlias;
    }

    public void setAppNameAlias(String appNameAlias) {
        this.appNameAlias = appNameAlias;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getHomeUrl() {
        return homeUrl;
    }

    public void setHomeUrl(String homeUrl) {
        this.homeUrl = homeUrl;
    }

    public Long getSwitches() {
        return switches;
    }

    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    /**
     * 判断开关值
     * @param systemSwitches
     * @return
     */
    public Boolean switchIsOpen(SystemSwitches systemSwitches){
         return SwitchUtils.switchIsOpen(switches,systemSwitches.getCode());
    }
}

==> sso-common-2.3.52-sources.jar: cn/com/duiba/sso/api/domain/dto/SystemDto.java <==
package cn.com.duiba.sso.api.domain.dto;

import cn.com.duiba.sso.api.domain.enums.SystemSwitches;
import cn.com.duiba.wolf.utils.SwitchUtils;

import java.io.Serializable;

/**
 * Created by liuyao on 2017/12/5.
 */
public class SystemDto implements Serializable {

    private Long id;
    private String appNameAlias;
    private String appName;
    private String icon;
    private String homeUrl;
    private Long switches;

    private Long bolId;///产线Id

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppNameAlias() {
        return appNameAlias;
    }

    public void setAppNameAlias(String appNameAlias) {
        this.appNameAlias = appNameAlias;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getHomeUrl() {
        return homeUrl;
    }

    public void setHomeUrl(String homeUrl) {
        this.homeUrl = homeUrl;
    }

    public Long getSwitches() {
        return switches;
    }

    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    /**
     * 判断开关值
     * @param systemSwitches
     * @return
     */
    public Boolean switchIsOpen(SystemSwitches systemSwitches){
         return SwitchUtils.switchIsOpen(switches,systemSwitches.getCode());
    }

    public Long getBolId() {
        return bolId;
    }

    public void setBolId(Long bolId) {
        this.bolId = bolId;
    }
}
